# TSR on Command Line

Browse thestudentroom.co.uk from the command line. Almost as lightweight as a real browser, and as strong and stable as the British government.

## Getting Started

### Prerequisites

#### Core

```
Python 3.5 or higher

```

#### Optional

Python libraries:

```
psutil (for displaying memory usage in non-POSIX operating systems)
nltk,inflect (for word-crunching)
tkinter (for matplotlib graphs - not pre-installed for Python 3 on some distros)
```

## Installation

```
pip install tsr
```

to use the PyPI repository version, or

```
pip install git+https://github.com/methmo/tsr
```

to use the latest version direct from this repository, replacing pip with pip3, depending on which version of python pip points to.

## License

MIT
